<?xml version="1.0" encoding="UTF-8"?>
<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2"
    xmlns:sqf="http://www.schematron-quickfix.com/validator/process">
    <!-- ||| Table rules ||| -->
    <!--Tables must contain headers-->
    <sch:pattern id="tableheadererror">
        <sch:rule context="table">
            <sch:assert test="(@conref) or (tgroup/thead)" role="warning">Tables must contain headers. Add table headers to your table.</sch:assert></sch:rule>
    </sch:pattern>
    
    <!--Avoid empty cells in table headers-->
     <sch:pattern id="table_header">
         <sch:rule context="thead/row/entry">
             <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;entry/> element in table headers.</sch:report>
        </sch:rule>
    </sch:pattern>
    
   <!--Tables must have titles-->
    <sch:pattern id="tabletitleerror">
        <sch:rule context="table">
            <sch:let name="header" value="(./tgroup/thead/row[1]/entry[1])"></sch:let>
            <sch:let name="row1" value="(./tgroup/tbody/row[1]/entry[1])"></sch:let>
            <sch:assert test="((title or @conref) and not($header = 'Callout' and (($row1 = 'A') or ($row1 = '1')))) or (not(title or @conref) and ($header = 'Callout' and (($row1 = 'A') or ($row1 = '1'))))" role="warning">
                A table must contain a title unless it is a callout table. For a standard table, add a title. For a callout table, do not add a title, but use 'Callout' for the first column header name.
            </sch:assert>
        </sch:rule>
    </sch:pattern>
    
    <!--Avoid empty values in table headings-->
    <sch:pattern id="tableheadererror2">
        <sch:rule context="table/title">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;title/> element in table headings.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| Figure rules ||| -->
    <!--Figures must have titles-->
    <sch:pattern id="figuretitleerror">
        <sch:rule context="fig">
            <sch:assert test="title" role="warning">Figures must contain titles. Add a title element.</sch:assert></sch:rule>
    </sch:pattern>
    
    <!--Avoid empty values in figure titles-->
    <sch:pattern id="figureheadererror2">
        <sch:rule context="fig/title">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;title/> element in figures.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| Image rules ||| -->
    <!-- Images must not have scalefit set -->
    <sch:pattern id="scalefiterror">
        <sch:rule context="image">
            <sch:assert test="not(@scalefit)" role="warning" sqf:fix="removeAttr">Images must not have scalefit set.</sch:assert>
            <sqf:fix id="removeAttr">
                <sqf:description>
                    <sqf:title>Remove @scalefit attribute</sqf:title>
                </sqf:description>
                <sqf:delete match="@scalefit"/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!-- Images must not have scale set -->
    <sch:pattern id="scaleerror">
        <sch:rule context="image">
            <sch:assert test="not(@scale)" role="warning" sqf:fix="removeAttr">Images must not have scale set.</sch:assert>
            <sqf:fix id="removeAttr">
                <sqf:description>
                    <sqf:title>Remove @scale attribute</sqf:title>
                </sqf:description>
                <sqf:delete match="@scale"/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| List rules ||| -->
    <!--Suggest breaking up lists when there are more than 9 list items-->
    <sch:pattern id="li_count">
        <!--This rule applies to both ol and ul lists-->
        <sch:rule context="ol|ul">
            <!--The line below creates a variable to store the number of list items-->    
            <sch:let name="listItems" value="count(li)"/>
            <!--lt/&lt; means less than, gt/&gt; means greater than-->
            <sch:assert test="count(li) lt 10" role="info">
                You have <sch:value-of select="$listItems"/> list items in this list. 
                Long lists of items can be overwhelming. 
                If the list exceeds 9 items, consider using more than one list.
            </sch:assert>
        </sch:rule>
    </sch:pattern>
    
    <!--Avoid lists when there is only one list item-->
    <sch:pattern id="one_li_ul">
        <!--This rule applies to both ol and ul lists-->
        <sch:rule context="ol|ul">
            <sch:report test="count(li) = 1" role="info">Do not create a list of only a single item.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Avoid hard coded text in xrefs -->
    <sch:pattern id="xrefError1">
    <sch:rule context="xref" id="empty">
        <sch:assert test="string-length(.) = 0" role="warning">
            The <sch:name/> element should be empty. Do not hard code link text.
        </sch:assert>
    </sch:rule>
    </sch:pattern>
    
    <!-- Avoid xrefs in a short description -->
    <sch:pattern id="no-linking-in-shortdesc" see="https://github.com/dita-ot/dita-ot/issues/3078">
        <sch:rule context="*[contains(@class, ' topic/shortdesc ')]">
            <sch:report test="*[@keyref] or *[contains(@href, '.dita')] or *[contains(@href, '')]" role="fatal">
                Do not include xrefs, bold, italics, underline, uicontrol etc. in &lt;shortdesc&gt;. This may break the PDF build.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Avoid empty values in context elements-->
    <sch:pattern id="context_error">
        <sch:rule context="context/p">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;p/> element in context elements.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Avoid an empty context element-->
    <sch:pattern id="context_error2">
        <sch:rule context="context">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;context/> element.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Avoid empty values in prereq elements-->
    <sch:pattern id="prereq_error">
        <sch:rule context="prereq/p">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;p/> element in prereq elements.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="prereq_error2">
        <sch:rule context="prereq">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty &lt;prereq/> element.</sch:report>
        </sch:rule>
    </sch:pattern>

    <!--Avoid ph tags with a single character-->
    <sch:pattern id="single_char_ph">
        <sch:rule context="ph">
            <sch:assert test="(string-length(normalize-space(.)) > 1) or exists(@keyref)" role="warning">
                Avoid empty ph tags or using ph tags with a single character
            </sch:assert>
        </sch:rule>
    </sch:pattern>
    
    <!--"denseTable" attribute and "firstcol" attribute cannot be used together-->
    <sch:pattern id="first_col_dense_table">
        <sch:rule context="table">
            <sch:report test="matches(@outputclass, 'mmpdf:denseTable') and matches(@rowheader, 'firstcol')" role="fatal">The attribute 'denseTable' and 'firstcol' cannot be used together. This may break the PDF build.</sch:report>
        </sch:rule>
    </sch:pattern>
    <!--Delete unnecessary elements if not needed-->
    <!--Problem with only deleting the node containing the error, need to find selectors for the containing nodes too-->
    <!--<sch:pattern>
        <sch:rule context="concept/conbody/p[1]">
            <sch:report test="(string-length(normalize-space(.)) = 0)" sqf:fix="delete_topic">
                It looks like this is an empty element. Do you want to delete the unnecessary tags?
            </sch:report>
            <sqf:fix id="delete_topic">
                <sqf:description>
                    <sqf:title>Delete the topic content if it is not needed.</sqf:title>
                </sqf:description>
                <sqf:delete ></sqf:delete>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>-->
    
    <!--Check for the presence of the xml:lang attribute in each topic-->
    <sch:pattern>
        <sch:rule context="concept|task|reference">
            <sch:assert test="@xml:lang" role="warning" sqf:fix="en_us_add add_xml_lang delete_topic">
                It is best practice to include the xml:lang attribute on the root element of the topic.
            </sch:assert>
            <sqf:fix id="en_us_add">
                <!--This rule adds an xml:lang attribute and set it to 'en-us'-->
                <sqf:description>
                    <sqf:title>Add the default en-us locale.</sqf:title>
                    <sqf:p>This action will add the xml-lang attribute to the topic and set it as 'en-us'.</sqf:p>
                </sqf:description>
                <sqf:add node-type="attribute" target="xml:lang">en-us</sqf:add>
            </sqf:fix>
            <sqf:fix id="add_xml_lang">
                <!--This rule allows the user to enter their chosen language and it will be set as the xml:lang attribute-->
                <sqf:description>
                    <sqf:title>Input the locale you are using and it will be added along with an xml:lang attribute.</sqf:title>
                    <sqf:p>This action will add the xml:lang attribute to the topic along with the locale you input.</sqf:p>
                </sqf:description>
                <sqf:user-entry name="language_attribute">
                    <sqf:description>
                        <sqf:title>Add the xml:lang attribute and locale.</sqf:title>
                    </sqf:description>
                </sqf:user-entry>
                <sqf:add node-type="attribute" target="xml:lang" select="$language_attribute" />        
            </sqf:fix>
            <!--This rule will delete the shortdesc and conbody topics if they're not needed-->
            <sqf:fix id="delete_topic">
                <sqf:description>
                    <sqf:title>Delete the topic content if it is not needed.</sqf:title>
                    <sqf:p>This action will affect concepts. It will delete the shortdesc and conbody.</sqf:p>
                </sqf:description>
                <sqf:delete match="shortdesc|conbody"></sqf:delete>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!--Check for the presence of the shortdesc element-->
    <sch:pattern id="noShortdesc">
        <sch:rule context="shortdesc">
            <sch:let name="words" value="count(tokenize(normalize-space(.), ' '))"/>
            <sch:assert test="$words gt 0" role="warning" sqf:fix="DeleteShortdesc">
                If the shortdesc element is not in use, delete it. From Author view, right-click on the shortdesc element, click Quick Fix, then click the dialog box.
            </sch:assert>
            <sqf:fix id="DeleteShortdesc">
                <sqf:description>
                    <sqf:title>Delete the unused shortdesc</sqf:title>
                </sqf:description>
                <sqf:delete match="."/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!-- Unordered list items must not end with a semicolon, comma or the word "and" -->
    <sch:pattern id="listpunctuation">
        <sch:rule context="ul/li" >
            <sch:report test="ends-with(text()[last()], ';')" role="info"> Do not end an unordered list
                item with a semicolon.</sch:report>
            <sch:report test="ends-with(text()[last()], ',')" role="info"> Do not end an unordered list
                item with a comma.</sch:report>
            <sch:report test="ends-with(text()[last()], ' and')" role="info"> Do not end an unordered list
                item with the word "and".</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Ordered list items must not end with a semicolon, comma or the word "and" -->
    <sch:pattern id="orderedlistpunctuation">
        <sch:rule context="ol/li" >
            <sch:report test="ends-with(text()[last()], ';')" role="info"> Do not end an ordered list
                item with a semicolon.</sch:report>
            <sch:report test="ends-with(text()[last()], ',')" role="info"> Do not end an ordered list
                item with a comma.</sch:report>
            <sch:report test="ends-with(text()[last()], ' and')" role="info"> Do not end an ordered list
                item with the word "and".</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Remove legacy oxy-placeholder text -->
    <sch:pattern id="oxy-placeholder">
        <sch:rule context="processing-instruction('oxy-placeholder')">
            <sch:report test="contains(., '')" role="error" sqf:fix="delete_oxy-placeholder">
                For image alt attributes, insert alternative text. For xrefs, remove legacy oxy-placeholder processing instructions because they interfere with translations. 
            </sch:report>
            <sqf:fix id="delete_oxy-placeholder">
                <sqf:description>
                    <sqf:title>Go to text view, and then click to delete the oxy-placeholder processing instruction.</sqf:title>
                </sqf:description>
                <sqf:delete/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
	
	<!-- Remove legacy ixia_locid text -->
	<sch:pattern id="ixia_locid">
		<sch:rule context="*">
			<sch:report test="@ixia_locid" role="error" sqf:fix="removeAttr">
           		Delete the ixia_locid attribute to avoid translation problems.
			</sch:report>
		<sqf:fix id="removeAttr">
			<sqf:description>
				<sqf:title>Delete @ixia_locid attribute</sqf:title>
			</sqf:description>
			<sqf:delete match="@ixia_locid"/>
		</sqf:fix>
		</sch:rule>
	</sch:pattern>
    
</sch:schema>
