<?xml version="1.0" encoding="UTF-8"?>
<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2"
    xmlns:sqf="http://www.schematron-quickfix.com/validator/process" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    
    <!-- A to I -->
    <!--Restrict values for the A section of Word Usage -->
    <!--Rule related to the word "above"-->
    <sch:pattern id="above">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (contains(., 'above') or contains(., 'Above'))" role="info">
                Do not use "above" to refer to the location of an image, figure, table, or another element in your topic. 
                Use a table number, figure number, or hyperlink to direct the user to the relevant part of the document.
            </sch:report>
         </sch:rule>
    </sch:pattern>
    
    <!--Rule related to the word "above"-->
    <sch:pattern id="alphanumerical">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(A|a)lphanumerical'))" role="info" sqf:fix="alphanumerical_fix">
                The term alphanumerical is not allowed. The correct term is 'alphanumeric'.
            </sch:report>
                <sqf:fix id="alphanumerical_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'alphanumeric'</sqf:title>
                        <sqf:p>Use the correct term, 'alphanumeric'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Alphanumerical">Alphanumeric</sqf:stringReplace>
                    <sqf:stringReplace regex="alphanumerical">alphanumeric</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="as_well">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (contains(., 'as well') or contains(., 'As well'))"
                role="info">Do not use "as well" to mean also or and.</sch:report>        
        </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for the B section of Word Usage -->    
    <sch:pattern id="below">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (contains(., ' below ') or contains(., ' Below '))" role="info">
                Do not use "below" to refer to the location of an image, figure, table, or another element in your topic. 
                Use a table number, figure number, or hyperlink to direct the user to the relevant part of the document.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for the C section of Word Usage -->
    <!--Do not use an apostrophie to contract the word cannot. Spell out the word in full.-->
    <sch:pattern id='cannot'>
        <sch:rule context="text()">
            <sch:report test='contains(/*/@xml:lang, "en-us") and matches(., "(C|c)an&apos;t")' role='info'>
                Do not use a contraction for can't in user documentation because it hinders readability.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--click here -->
    <sch:pattern id="click_here">
        <sch:rule context="text()">
            <sch:report test="matches(., '(C|c)lick here')" role="info">
                Avoid using the term click here. Use the page title or subject of the location to click or revise your sentence. 
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="crash">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'crash')"
                role="info">Do not use "crash" to refer to a technical mishap or an unresponsive computer or device.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Crash')"
                role="info"
               >Do not use "crash" to refer to a technical mishap or an unresponsive computer or device.</sch:report>
            </sch:rule>
    </sch:pattern>
    
    <sch:pattern id='customise'>
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(C|c)ustomise(\s|$|\W)') or matches(., '(C|c)ustomisation(\s|$|\W)'))" role="warning" sqf:fix="customise_fix">
                Note that there are two variations of spelling for customise or customize.
                Use the American English spelling of customize for an American audience and the British English spelling customise for UK or European audiences.</sch:report> 
            <sqf:fix id="customise_fix">
                <sqf:description>
                    <sqf:title>Replace with American English term:'customize' or 'customization'</sqf:title>
                </sqf:description>
                <sqf:stringReplace regex="Customise">Customize</sqf:stringReplace>
                <sqf:stringReplace regex="customise">customize</sqf:stringReplace>
                <sqf:stringReplace regex="Customisation">Customization</sqf:stringReplace>
                <sqf:stringReplace regex="customisation">customization</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>

    <sch:pattern id='colour'>
        <sch:rule context="text()">
            <sch:report test= 'contains(/*/@xml:lang, "en-us") and matches(., "(C|c)olour(\s|$|\W)")' role='warning' sqf:fix='colour_fix'>
                Note that there are two variations of spelling for colour or color.
                Use the American English spelling of color for an American audience and the British spelling colour for UK or European audiences.</sch:report>
                <sqf:fix id="colour_fix">
                    <sqf:description>
                        <sqf:title>Replace with American English term:'color'</sqf:title>
                    </sqf:description>
                    <sqf:stringReplace regex="Colour">Color</sqf:stringReplace>
                    <sqf:stringReplace regex="colour">color</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>

    <!--Restrict values for the D section of Word Usage -->
    <sch:pattern id="default">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'default')"
                role="info">Use "default" with caution. Where possible, use the word default as a noun rather than a verb.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Default')"
                role="info">Use "default" with caution. Where possible, use the word default as a noun rather than a verb.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Do not use desire in technical communication -->
    <sch:pattern id="desire">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'desire')"
                role="info"
                sqf:fix="sqfGrouptest1">There is no "desire" in technical communication. Rewrite the sentence and substitute the word desire for a more appropriate word like want.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Desire')"
                role="info"
                sqf:fix="sqfGrouptest1">There is no "desire" in technical communication. Rewrite the sentence and substitute the word desire for a more appropriate word like want.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'want'</sqf:title>
                        <sqf:p>Use the correct term, 'want'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="desire">want</sqf:stringReplace>
                    <sqf:stringReplace regex="Desire">Want</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not use an apostrophie to contract the words do and not. Spell out the words do and not.-->
    <sch:pattern id="do_not">
        <sch:rule context="text()">
            <sch:report test='contains(/*/@xml:lang, "en-us") and matches(., "(D|d)on&apos;t")' role='info'>
                Do not use a contraction for don't in user documentation because it hinders readability.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="drag-and-drop">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'drag-and-drop')"
                role="info">Use "drag-and-drop" only as an adjective, not as a noun or as a verb.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Drag-and-Drop')"
                role="info">Use "drag-and-drop" only as an adjective, not as a noun or as a verb.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for the E section of Word Usage -->
    <sch:pattern id="e.g.">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'e.g.')"
                role="warning"
                sqf:fix="sqfGrouptest1">Write "e.g." in its full format. Use “for example” instead of e.g..</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'E.G.')"
                role="warning"
                sqf:fix="sqfGrouptest1">Write "e.g." in its full format. Use “for example” instead of e.g..</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'for example'</sqf:title>
                        <sqf:p>Use the correct term, 'for example'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="(E|e).(G|g).">for example</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="etc.">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'etc.')"
                role="warning">Do not use "etc." Do not use the phrase "and so on" instead of etc. Rewrite the sentence.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Etc.')"
                role="warning">Do not use "etc." Do not use the phrase "and so on" instead of etc. Rewrite the sentence.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="ethernet">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'ethernet')"
                role="info"
                sqf:fix="sqfGrouptest1">Capitalize "Ethernet".</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'Ethernet'</sqf:title>
                        <sqf:p>Use the correct term, 'Ethernet'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="ethernet">Ethernet</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="extinguish">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(E|e)xtinguish')" role="info" sqf:fix="extinguish_fix">
                The term 'extinguish' is not allowed. The correct term is 'suppress'.
            </sch:report>            
            <sqf:fix id="extinguish_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'suppress'</sqf:title>
                    <sqf:p>Use the correct term, 'suppress'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Extinguish">Suppress</sqf:stringReplace>
                <sqf:stringReplace regex="extinguish">suppress</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for the F section of Word Usage -->
    
    <sch:pattern id='favourite'>
        <sch:rule context="text()">
            <sch:report test= 'contains(/*/@xml:lang, "en-us") and matches(., "(F|f)avourite(\s|$|\W)")' role='warning' sqf:fix='favourite_fix'>
                Note that there are two variations of spelling for favorite or favourite.
                Use the American English spelling of favorite for an American audience and the British spelling favourite for UK or European audiences.</sch:report>
            <sqf:fix id="favourite_fix">
                <sqf:description>
                    <sqf:title>Replace with American English term:'favorite'</sqf:title>
                </sqf:description>
                <sqf:stringReplace regex="Favourite">Favorite</sqf:stringReplace>
                <sqf:stringReplace regex="favourite">favorite</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for the G section of Word Usage -->
    
    <sch:pattern id='grey'>
        <sch:rule context="text()">
            <sch:report test='contains(/*/@xml:lang, "en-us") and matches(., "(^|)(G|g)rey(\s|$|\W)")' role='warning' sqf:fix='grey_fix'> 
               Note that there are two variations of spelling for the color grey or gray. 
               Use the American English spelling of gray for an American audience and the British English spelling grey for UK and European audiences.</sch:report>
            <sqf:fix id="grey_fix">
                <sqf:description>
                    <sqf:title>Replace with American English term: 'gray'</sqf:title>
                </sqf:description>
                <sqf:stringReplace regex="Grey">Gray</sqf:stringReplace>
                <sqf:stringReplace regex="grey">gray</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
       
    <sch:pattern id='globalise'>
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(G|g)lobalise(\s|$|\W)') or matches(., '(G|g)lobalisation(\s|$|\W)'))" role="warning" sqf:fix="globalise_fix"> 
                Note that there are two variations of spelling for globalise or globalize.
                Use the American English spelling of globalize for an American audience and the British English spelling globalise for UK or European audiences.</sch:report>
                <sqf:fix id="globalise_fix">
                    <sqf:description>
                        <sqf:title>Replace with American English term:'globalize' or 'globalization'</sqf:title>
                    </sqf:description>
                    <sqf:stringReplace regex="Globalise">Globalize</sqf:stringReplace>
                    <sqf:stringReplace regex="globalise">globalize</sqf:stringReplace>
                    <sqf:stringReplace regex="Globalisation">Globalization</sqf:stringReplace>
                    <sqf:stringReplace regex="globalisation">globalization</sqf:stringReplace>
                </sqf:fix>
            </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for the I section of Word Usage -->
    
    <sch:pattern id="i.e.">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'i.e.')"
                role="warning"
                sqf:fix="sqfGrouptest1">Write "i.e." in its full format. Use “that is” instead of i.e..</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'I.E.')"
                role="warning"
                sqf:fix="sqfGrouptest1">Write "i.e." in its full format. Use “that is” instead of i.e..</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'that is'</sqf:title>
                        <sqf:p>Use the correct term, 'that is'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="(I|i).(E|e).">that is</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="internet">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'internet')"
                role="info"
                sqf:fix="sqfGrouptest1">When you write about the "Internet" as a proper noun, use title case. When you write about an internet connection where internet is an adjective, use sentence case.</sch:report>
                                        <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'Internet'</sqf:title>
                        <sqf:p>Use the correct term, 'Internet'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="internet">Internet</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern> 
        
    <!--Do not use an apostrophie to contract the words It and is. Spell out the words in full.-->
    <sch:pattern id='It_is'>
        <sch:rule context="text()">
            <sch:report test='contains(/*/@xml:lang, "en-us") and matches(., "(^|\s)(I|i)t&apos;s")' role='info' sqf:fix="it_is_fix"> 
                Do not use a contraction for It's in user documentation because it hinders readability. Spell out the words in full.</sch:report>
                       <sqf:fix id="it_is_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: It is</sqf:title>
                        <sqf:p>Use the correct term, It is</sqf:p>
                    </sqf:description>
                <sqf:stringReplace regex="It&apos;s">It is</sqf:stringReplace>
                           <sqf:stringReplace regex="it&apos;s">it is</sqf:stringReplace>
                       </sqf:fix>
                     </sch:rule>
    </sch:pattern>
 
      <!-- J to L -->
    <!--Restrict values J section of Word Usage -->
    <!--Do not use the acronym JCI. Spell out the words Johnson Controls and do not use Inc. -->
    <sch:pattern id="JCI">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., 'JCI')" role="warning" sqf:fix="jci_fix">
                Do not use the acronym "JCI". Spell out the words Johnson Controls and do not use Inc.
            </sch:report>
                <sqf:fix id="jci_fix">
                    <sqf:description> 
                        <sqf:title>Replace with allowed term: 'Johnson Controls'</sqf:title>
                        <sqf:p>Use the correct name, 'Johnson Controls'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="JCI">Johnson Controls</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
   
    <!--Restrict values L section of Word Usage -->
    
    <sch:pattern id="locking_screen">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'locking screen')" role="info" sqf:fix="locking_screen_fix">
                Use "screen lock" to refer to the security feature on a mobile device that requires the user to enter a pin or draw a pattern to access the phone.
            </sch:report>
            <sqf:fix id="locking_screen_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'screen lock'</sqf:title>
                    <sqf:p>Use the correct term, 'screen lock'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Locking screen">Screen lock</sqf:stringReplace>
                <sqf:stringReplace regex="locking screen">screen lock</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="login">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'login')"
                role="info"
                sqf:fix="sqfGrouptest1">Do not use "login" unless this term appears as a label on the user interface.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Login')"
                role="info"
                sqf:fix="sqfGrouptest1">Do not use "login" unless this term appears as a label on the user interface.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Replace with an allowed term: 'log on'</sqf:title>
                        <sqf:p>Use the correct term, 'log on'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Login">Log on</sqf:stringReplace>
                    <sqf:stringReplace regex="login">log on</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="log_in">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(L|l)og in ')" role="info" sqf:fix="log_in_fix">
                Do not use "log in" unless this term appears as a label on the user interface.
            </sch:report>
            <sqf:fix id="log_in_fix">
                <sqf:description> 
                    <sqf:title>Replace with an allowed term: 'log on'</sqf:title>
                    <sqf:p>Use the correct term, 'log on'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Log in">Log on</sqf:stringReplace>
                <sqf:stringReplace regex=" log in "> log on </sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
 
    <sch:pattern id="logout">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(L|l)ogout')" role="info" sqf:fix="logout_fix">
                Do not use "logout" unless this term appears as a label on the user interface.
            </sch:report>
            <sqf:fix id="logout_fix">
                <sqf:description> 
                    <sqf:title>Replace with an allowed term: 'log off'</sqf:title>
                    <sqf:p>Use the correct term, 'log off'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Logout">Log off</sqf:stringReplace>
                <sqf:stringReplace regex="logout">log off</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
 
    <sch:pattern id="log_out">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(^|\s)(L|l)og out')" role="info" sqf:fix="log_out_fix">
                Do not use "log out" unless this term appears as a label on the user interface.
            </sch:report>
            <sqf:fix id="log_out_fix">
                <sqf:description> 
                    <sqf:title>Replace with an allowed term: 'log off'</sqf:title>
                    <sqf:p>Use the correct term, 'log off'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Log out">Log off</sqf:stringReplace>
                <sqf:stringReplace regex=" log out"> log off</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
 
    <!--Restrict values K section of Word Usage -->
    <sch:pattern id="keylock">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(K|k)eylock')"
                role="info"
                sqf:fix="keylock_fix">Use "screen lock" to refer to the security feature on a mobile device that requires the user to enter a pin or draw a pattern to access the phone.</sch:report>
            <sqf:fix id="keylock_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'screen lock'</sqf:title>
                    <sqf:p>Use the correct term, 'screen lock'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Keylock">Screen lock</sqf:stringReplace>
                <sqf:stringReplace regex="keylock">screen lock</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
 
    <!--Restrict values for M to S section of Word Usage -->   
    <!--Restrict use of the word "may"-->
    <sch:pattern id="may">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(M|m)ay')" role="info">
                Use "may" only to describe the possibility of an event occurring. Do not use may to apply to permission the user can have. Consider rewriting the sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--  Ensure the correct spelling of the word "off-premises"  -->
    <sch:pattern id="OffPrem">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(O|o)ff premises(\s|$|\W)') or matches(., '(O|o)ff-premise(\s|\W|$)') or matches(., '(O|o)ff premise(\s|$|\W)') or matches(., '(O|o)ff-prem(\s|$|\W)') or matches(., '(O|o)ff prem(\s|$|\W)'))" role="info">
                Hyphenate in all positions. Note that premises is plural. Do not use off-premise.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--  Ensure the correct spelling of the word "on-premises"  -->
    <sch:pattern id="OnPrem">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(^|\s)(O|o)n premises(\s|$|\W)') or matches(., '(^|\s)(O|o)n-premise(\s|$|\W)') or matches(., '(^|\s)(O|o)n premise(\s|$|\W)') or matches(., '(^|\s)(O|o)n-prem(\s|$|\W)') or matches(., '(^|\s)(O|o)n prem(\s|$|\W)'))" role="info">
                Hyphenate in all positions. Note that premises is plural. Do not use on-premise.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="should">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(S|s)hould(\s|\W|$)'))"
                role="info">Avoid using "should". Consider rewriting the sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
 
    <!--see here -->
    <sch:pattern id="see_here">
        <sch:rule context="text()">
            <sch:report test="matches(., '(S|s)ee here')" role="info">
                Avoid using the term see here. Use the title or the subject of the location to see or revise your sentence. 
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="Part_no.">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., 'Part no.')" role="warning" sqf:fix="part_no_fix">
                Always capitalize "No." when used in Part No. Otherwise, use number.
             </sch:report>
            <sqf:fix id="part_no_fix">
                <sqf:description> 
                    <sqf:title>Replace with an allowed term: 'Part No.'</sqf:title>
                    <sqf:p>Use the correct term, 'Part No.'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Part no.">Part No.</sqf:stringReplace>
                <sqf:stringReplace regex="part no.">Part No.</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
<!-- changed to remove check for extra space and added quick fixes -->
    <sch:pattern id="onboard">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(O| o)n board') or matches(., '(O| o)n-board'))" 
                role="info" sqf:fix="onboard_fix">
                "on board or on-board" is incorrect. The correct word is "onboard", one word.
            </sch:report>
            <sqf:fix id="onboard_fix">
                <sqf:description> 
                    <sqf:title>Replace with an allowed term: 'onboard'</sqf:title>
                    <sqf:p>Use the correct term, 'onboard'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="on board">onboard</sqf:stringReplace>
                <sqf:stringReplace regex="On board">Onboard</sqf:stringReplace>
		<sqf:stringReplace regex="on-board">onboard</sqf:stringReplace>
                <sqf:stringReplace regex="On-board">Onboard</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="once">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (contains(., ' once ') or contains(., 'once.') or contains(., 'Once '))" role="info"
                sqf:fix="termtest1">To avoid ambiguity, especially for the global audience, do not use "once" as a synonym for when or after.
            </sch:report>
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Replace with an allowed term: 'when'</sqf:title>
                        <sqf:p>Use the correct term, 'when'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex=" once "> when </sqf:stringReplace>
                    <sqf:stringReplace regex="Once">When</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="only">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' only ')"
                role="info"
                sqf:fix="sqfGrouptest1">Use the modifier "only" with caution. Place "only" immediately before whatever it modifies. Inconsistent placement of only can cause mistranslations and variation in translation memory.
            </sch:report>
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Remove the word "only" from the sentence.</sqf:title>
                    </sqf:description>
                    <sqf:stringReplace regex=" only ">  </sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
<!-- changed to allow onscreen as part of a word but not allow Onscreen anywhere -->    
    <sch:pattern id="onscreen">
        <sch:rule context="text()">
	    <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., ' onscreen') or matches(., 'Onscreen'))"
                role="info"
                sqf:fix="sqfGrouptest1">Hyphenate "on-screen" as an adjective. Instead of using on-screen as an adverb, try to rewrite the sentence by using a phrase such as on the screen.
            </sch:report>           
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Replace with an allowed term: 'on-screen'</sqf:title>
                        <sqf:p>Use the correct term, 'on-screen'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="onscreen">on-screen</sqf:stringReplace>
		    <sqf:stringReplace regex="Onscreen">On-screen</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
<!-- changed to exclude things like common screen from being flagged -->
    <sch:pattern id="onscreen_2">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., 'On screen') or matches(., ' on screen'))"
                role="info"
                sqf:fix="sqfGrouptest1">Hyphenate "on-screen" as an adjective. Instead of using on-screen as an adverb, try to rewrite the sentence by using a phrase such as on the screen.
            </sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Replace with an allowed term: 'on-screen'</sqf:title>
                        <sqf:p>Use the correct term, 'on-screen'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="on screen">on-screen</sqf:stringReplace>
		    <sqf:stringReplace regex="On screen">On-screen</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern> 
 
    <sch:pattern id="orient">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'orientate')"
                role="warning"
                sqf:fix="sqfGrouptest1">The term orientate is not allowed. The correct term is 'orient'.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Orientate')"
                role="warning"
                sqf:fix="sqfGrouptest1">The term 'orientate' is not allowed. The correct term is 'orient'.</sch:report>
           
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'orient'</sqf:title>
                        <sqf:p>Use the correct term, 'orient'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Orientate">Orient</sqf:stringReplace>
                    <sqf:stringReplace regex="orientate">orient</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="outdoor">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., 'outdoor')"
                role="info"
                sqf:fix="sqfGrouptest1">Outside is preferred, but you can use "outdoor" to match the usage in the name of an existing product.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., 'Outdoor')"
                role="info"
                sqf:fix="sqfGrouptest1">Outside is preferred, but you can use "outdoor" to match the usage in the name of an existing product.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'outside'</sqf:title>
                        <sqf:p>Use the correct term, 'outside'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Outdoor">Outside</sqf:stringReplace>
                    <sqf:stringReplace regex="outdoor">outside</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <!-- Warn against using the word "per" -->
    <sch:pattern id="per">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' per ')"
                role="warning"
                sqf:fix="sqfGrouptest1">Use "per" with caution. Per is an acceptable term in technical specifications, statistical contexts, or factors, but avoid using it in regular text.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Replace with an allowed term: ' for each '</sqf:title>
                        <sqf:p>Use the correct term, ' for each '</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex=" per "> for each </sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="please">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'please')"
                role="info">Do not use "please" in any technical documentation. Terms of politeness convey the wrong tone for technical material.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Please')"
                role="info">Do not use "please" in any technical documentation. Terms of politeness convey the wrong tone for technical material.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="populate">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'populate')"
                role="info"
                sqf:fix="sqfGrouptest1">Do not use "populate". Use fill, complete, or another synonym.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Populate')"
                role="info"
                sqf:fix="sqfGrouptest1">Do not use "populate". Use fill, complete, or another synonym.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'complete'</sqf:title>
                        <sqf:p>Use the correct term, 'complete'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Populate">Complete</sqf:stringReplace>
                    <sqf:stringReplace regex="populate">complete</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="power_down">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'power down')"
                role="info"
                sqf:fix="sqfGrouptest1">Try to avoid "power down". The preference is to use turn off or turn on.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Power down')"
                role="info"
                sqf:fix="sqfGrouptest1">Try to avoid "power down". The preference is to use turn off or turn on.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'turn off'</sqf:title>
                        <sqf:p>Use the correct term, 'turn off'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Power down">Turn off</sqf:stringReplace>
                    <sqf:stringReplace regex="power down">turn off</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="power_up">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(P|p)ower up')" role="info" sqf:fix="powerup">
                Try to avoid "power up". The preference is to use turn off or turn on.
            </sch:report>
            <sqf:fix id="powerup">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'turn on'</sqf:title>
                    <sqf:p>Use the correct term, 'turn on'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Power up">Turn on</sqf:stringReplace>
                <sqf:stringReplace regex="power up">turn on</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="prior_to">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(P|p)rior to')" role="warning" sqf:fix="prior">
                Use "before" instead of "prior to".
            </sch:report>
                <sqf:fix id="prior">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term</sqf:title>
                        <sqf:p>Use the correct term, 'before'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Prior to">Before</sqf:stringReplace>
                    <sqf:stringReplace regex="prior to">before</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="properly">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(P|p)roperly')" role="warning" sqf:fix="properly">
                Replace "properly" with "correctly". Follow a procedure correctly, not properly.
            </sch:report>            
                <sqf:fix id="properly">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'correctly'</sqf:title>
                        <sqf:p>Use the correct term, 'correctly'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Properly">Correctly</sqf:stringReplace>
                    <sqf:stringReplace regex="properly">correctly</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="qty">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'qty')"
                role="info"
                sqf:fix="sqfGrouptest1">Quantity. No period. Spell out "quantity" except in tables if space is a concern.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Qty')"
                role="info"
                sqf:fix="sqfGrouptest1">Quantity. No period. Spell out "quantity" except in tables if space is a concern.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'quantity'</sqf:title>
                        <sqf:p>Use the correct term, 'quantity'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Qty">Quantity</sqf:stringReplace>
                    <sqf:stringReplace regex="qty">quantity</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="reboot">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'reboot')"
                role="info"
                sqf:fix="sqfGrouptest1">Use "restart" instead of "reboot".</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Reboot')"
                role="info"
                sqf:fix="sqfGrouptest1">Use "restart" instead of "reboot".</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'restart'</sqf:title>
                        <sqf:p>Use the correct term, 'restart'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Reboot">Restart</sqf:stringReplace>
                    <sqf:stringReplace regex="reboot">restart</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="recommend">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'recommend')"
                role="warning"
                sqf:fix="sqfGrouptest1">Avoid using "recommend".</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Recommend')"
                role="warning"
                sqf:fix="sqfGrouptest1">Avoid using "recommend".</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: ' '</sqf:title>
                        <sqf:p>Use the correct term, ' '</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Recommend"> </sqf:stringReplace>
                    <sqf:stringReplace regex="recommend"> </sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="run_time">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'run time')"
                role="info"
                sqf:fix="sqfGrouptest1">"Runtime", one word.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Run time')"
                role="info"
                sqf:fix="sqfGrouptest1">"Runtime", one word.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'runtime'</sqf:title>
                        <sqf:p>Use the correct term, 'runtime'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Run time">Runtime</sqf:stringReplace>
                    <sqf:stringReplace regex="run time">runtime</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="sign_off">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'sign off')"
                role="info"
                sqf:fix="sqfGrouptest1">Do not use "sign off" unless this term appears as a label on the user interface.</sch:report>
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'Sign off')"
                role="info"
                sqf:fix="sqfGrouptest1">Do not use "sign off" unless this term appears as a label on the user interface.</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description> 
                        <sqf:title>Replace with an allowed term: 'log off'</sqf:title>
                        <sqf:p>Use the correct term, 'log off'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Sign off">Log off</sqf:stringReplace>
                    <sqf:stringReplace regex="sign off">log off</sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="sign_on">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(^|\s)(S|s)ign on(\s|$|\W)')" role="info" sqf:fix="sign_on_fix">
                Do not use "sign on" unless this term appears as a label on the user interface or as part of the term single sign on (SSO).
            </sch:report>
            <sqf:fix id="sign_on_fix">
                <sqf:description> 
                    <sqf:title>Replace with an allowed term: 'log on'</sqf:title>
                    <sqf:p>Use the correct term, 'log on'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Sign on">Log on</sqf:stringReplace>
                <sqf:stringReplace regex="sign on">log on</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="screenlock">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(S|s)creenlock')" role="info" sqf:fix="screenlock_fix">
                Use the acceptable spelling "screen lock" to refer to the security feature on a mobile device that requires the user to enter a pin or draw a pattern to access the phone.
            </sch:report>
            <sqf:fix id="screenlock_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'screen lock'</sqf:title>
                    <sqf:p>Use the correct term, 'screen lock'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Screenlock">Screen lock</sqf:stringReplace>
                <sqf:stringReplace regex="screenlock">screen lock</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="selection">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(S|s)election(\s|$|\W)')"
                role="info">Use "selection" with caution. Consider rewriting the sentence using a more appropriate word or phrase.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="shall">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(^|\s)(S|s)hall(\s|$|\W)')" role="warning">
                Do not use "shall" unless your business unit requires it for regulatory or legal reasons.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="since">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(S|s)ince(\s|\W|$)')" role="info">
                Do not use "since" to denote a conjunction. Consider rewriting the sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="slave">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(S|s)lave')" role="warning" sqf:fix="slave_fix">
                Do not use the word "slave". In most instances use "subordinate". Consult your BU if in doubt.</sch:report>
                <sqf:fix id="slave_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'subordinate'</sqf:title>
                        <sqf:p>Use the correct term, 'subordinate'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Slave">Subordinate</sqf:stringReplace>
                    <sqf:stringReplace regex="slave">subordinate</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="super_user">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(S|s)uper user')" role="info" sqf:fix="super_user_fix">
                "Superuser" is one word, unless it is different in a particular software application.</sch:report>
                <sqf:fix id="super_user_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'superuser'</sqf:title>
                        <sqf:p>Use the correct term, 'superuser'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="Super user">Superuser</sqf:stringReplace>
                    <sqf:stringReplace regex="super user">superuser</sqf:stringReplace>
                </sqf:fix>            
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="swap_out">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(S|s)wap out')" role="info" sqf:fix="swap_out_fix">
                Do not use "swap out". Use replace, exchange, or substitute.
            </sch:report>
            <sqf:fix id="swap_out_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'replace'</sqf:title>
                    <sqf:p>Use the correct term, 'replace'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="Swap out">Replace</sqf:stringReplace>
                <sqf:stringReplace regex="swap out">replace</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="sync">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'sync')"
                role="info">Caution, do not use "sync" as a noun, only as a verb.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Restrict values for T to Z section of Word Usage -->
    <!--Do not use 3rd party-->
    <sch:pattern id="thirdParty">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '3rd(\s|\W)party') or matches(., '(T|t)hirdparty'))" role="info">
                Do not use 3rd party. Spell out and hyphenate when used as an adjective, such as third-party approval. Do not hyphenate when used as a noun.</sch:report>
            <!--quickfix WIP
                <sqf:fix id="thirdpartyfix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'third-party'</sqf:title>
                    <sqf:p>Use the correct term, 'third-party'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="3rd party">Third-party</sqf:stringReplace>
                <sqf:stringReplace regex="3rd party">third-party</sqf:stringReplace>
                <sqf:stringReplace regex="^3rd Party">Third-party</sqf:stringReplace>
                <sqf:stringReplace regex="^3rd Party">third-party</sqf:stringReplace>
                <sqf:stringReplace regex="Thirdparty">Third-party</sqf:stringReplace>
                <sqf:stringReplace regex="thirdparty">third-party</sqf:stringReplace>
            </sqf:fix> -->
        </sch:rule>
    </sch:pattern>
    <sch:pattern id="thus">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(T|t)hus')" role="warning">
                Do not use "thus".
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="therefore">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(T|t)herefore')" role="warning">
                Do not use "therefore".
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="thru">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '\sthru\s') or matches(., 'Thru\s') or matches(., '\dthru\d'))"
                role="warning"
                sqf:fix="sqfGrouptest1">Do not use "thru". Replace with "through".</sch:report>
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'through'</sqf:title>
                        <sqf:p>Use the correct term, 'through'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="(|\s)thru(|\s)"> through </sqf:stringReplace>
                    <sqf:stringReplace regex="(\s)Thru(|\s)"> Through </sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>

    </sch:pattern>
    <sch:pattern id="towards">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(T|t)owards')" role="info" sqf:fix="towards_fix">
                Do not use "towards". Use "toward".
            </sch:report>
                <sqf:fix id="towards_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'toward'</sqf:title>
                        <sqf:p>Use the correct term, 'toward'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="towards">toward</sqf:stringReplace>
                    <sqf:stringReplace regex="Towards">Toward</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="typically">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(T|t)ypically'))"
                role="info">
                Do not state that processes or events are "typically" done a certain way. Typically adds a vagueness that we want to avoid in our content.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--  Ensure the correct spelling of the word "United States"  -->
    <sch:pattern id="united_states">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(U|u)nited states(\W|\s|$)'))" role="info" sqf:fix="united_states_fix">
                In normal text, spell out United States as a noun. Reserve US for the adjective form only, for example, US dollars.
            </sch:report>
            <sqf:fix id="united_states_fix">
                <sqf:description>
                    <sqf:title>Replace with the correct spelling: 'United States'</sqf:title>
                    <sqf:p>Use the correct spelling, 'United States'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="(U|u)nited states">United States</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!--  Ensure the correct spelling of the word "USB"  -->
    <sch:pattern id="USB">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(\s|^)(U|u)sb(\s|$)') or matches(., '(^|\s)USb(\s|$)') or matches(., '(^|\s)USb(\s|$)'))" role="info" sqf:fix="USBFix">
                The correct spelling is "USB"
            </sch:report>
            <sqf:fix id="USBFix">
                <sqf:description>
                    <sqf:title>Replace incorrect spelling with correct spelling.</sqf:title>
                    <sqf:p>This is extra text.</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="(U|u)(S|s)b">USB</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>

    <sch:pattern id="user_name">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(U|u)sername')" role="info" sqf:fix="username_fix">
                The correct term is "user name", unless you are describing a label in the UI.
            </sch:report>
                <sqf:fix id="username_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'user name'</sqf:title>
                        <sqf:p>Use the correct term, 'user name'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="username">user name</sqf:stringReplace>
                    <sqf:stringReplace regex="Username">User name</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="utilize">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(U|u)tilize')" role="info" sqf:fix="utilize_correction">
                Replace "utilize" with "use".
            </sch:report>        
                <sqf:fix id="utilize_correction">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'use'</sqf:title>
                        <sqf:p>Use the correct term, 'use'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="utilize">use</sqf:stringReplace>
                    <sqf:stringReplace regex="Utilize">Use</sqf:stringReplace>
                </sqf:fix>
            
        </sch:rule>
    </sch:pattern>

    <!--    Restrict values for the V section of Word Usage-->

    <sch:pattern id="via">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' via ')"
                role="warning"
                sqf:fix="sqfGrouptest1">Avoid Latin words and phrases such as "via".</sch:report>
            
            <sqf:group id="sqfGrouptest1">
                <sqf:fix id="termtest1">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'through'</sqf:title>
                        <sqf:p>Use the correct term, 'through'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex=" via "> through </sqf:stringReplace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="vs">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '\s(V|v)s\s')" role="warning" sqf:fix="vs_correction">
                Spell out "vs" in text. In headings, use a period and do not capitalize.
            </sch:report>
                <sqf:fix id="vs_correction">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'versus'</sqf:title>
                        <sqf:p>Use the correct term, 'versus'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex=" (Vs|vs) "> versus </sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="web">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' Web ')" role="info" sqf:fix="web_fix">
                Do not capitalize "Web" except in the phrase World Wide Web.
            </sch:report>
            <sqf:fix id="web_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'web'</sqf:title>
                    <sqf:p>Use the correct term, 'web'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex=" Web "> web </sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="which">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' which ')"
                role="info">Use "which" with caution. Use "that" before a restrictive clause, and use "which" before a nonrestrictive clause.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    
    <sch:pattern id="wish">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' wish ')" role="info" sqf:fix="web_fix">
                Use want instead of "wish".
            </sch:report>
            <sqf:fix id="web_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'want'</sqf:title>
                    <sqf:p>Use the correct term, 'want'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex=" wish "> want </sqf:stringReplace>
            </sqf:fix> 
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="within">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'within')" role="info" sqf:fix="within_fix">
                Use "within" with caution. Use within only to indicate a sense of enclosure. For example, the control fits within the case. Use "in" for other senses
            </sch:report>
            <sqf:fix id="within_fix">
                <sqf:description>
                    <sqf:title>Replace with an allowed term: 'in'</sqf:title>
                    <sqf:p>Use the correct term, 'in'</sqf:p>
                </sqf:description>
                <sqf:stringReplace regex="within">in</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="wrong">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '(W|w)rong')" role="warning" sqf:fix="wrong_fix">
                "Wrong" is wrong. Use incorrect.
            </sch:report>
                <sqf:fix id="wrong_fix">
                    <sqf:description>
                        <sqf:title>Replace with an allowed term: 'incorrect'</sqf:title>
                        <sqf:p>Use the correct term, 'incorrect'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="wrong">incorrect</sqf:stringReplace>
                    <sqf:stringReplace regex="Wrong">Incorrect</sqf:stringReplace>
                </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    
    <!--Restrict future tense -->
    <sch:pattern id="will">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., ' (W|w)ill ')" role="info">
                Avoid using "will" unless dictated by legal departments. Rewrite the sentence, if possible. 
                In technical documentation, you must always write in the present tense.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    
    <!--Restrict anthropomorphic terms -->
    <sch:pattern id="permit">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'permit')" role="info">
                Use "permit" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="behave">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'behave')" role="info">
                Use "behave" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>        
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="refuse">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'refuse')" role="info">
                Use "refuse" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="think">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'think')" role="info">
                Use "think" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="knows">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'knows')" role="info">
                Use "knows" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="realize">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'realize')" role="info">
                Use "realize" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
   
    <sch:pattern id="likes">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' likes ')" role="info">
                Use "likes" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="allow">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' allow ')" role="info">
                Use "allow" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="allowed">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' allowed ')" role="info">
                Do not use "allowed". Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="allowable">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., 'allowable')" role="info">
                Do not use "allowable". Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="lets">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' lets ')" role="info">
                Do not use "lets". Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="let">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' let ')" role="info">
                Use "let" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="expect">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' expect ')" role="info">
                Use "expect" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="expects">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ' expects ')" role="info">
                Use "expects" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="offer">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '\soffer\s')" role="info">
                Use "offer" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    
    <sch:pattern id="enable">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and matches(., '\senable\s')" role="info">
                Use "enable" with caution. Avoid attributing human characteristics to devices and software. Avoid anthropomorphic words and phrases.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| Restrict values for grammar ||| -->

    <!-- Do not begin a sentence with it -->
    <sch:pattern>
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and starts-with(., 'It ')" role="info">
                Do not begin a sentence with it.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Warn that it is not recommended to start a sentence with 'There is' or 'There are'-->
    <sch:pattern>
        <sch:rule context="p | li">
            <sch:report test="matches(., 'There is') or matches(., 'There are')" role="info">Do not start sentences with There is or There are. Use straightforward verb phrases instead of wordy or oblique ones.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not start a sentence with 'In this topic' -->
    <sch:pattern id="In_this_topic">
        <sch:rule context="text()">
            <sch:report test="matches(., '(I|i)n this topic')" role="info">
                Avoid introducing a topic by writing the phrase in this topic. Use a meaningful topic or revise your sentence. 
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not start a sentence with 'In this section' -->
    <sch:pattern id="In_this_section">
        <sch:rule context="text()">
            <sch:report test="matches(., '(I|i)n this section')" role="info">
                Avoid introducing a section by writing the phrase in this section. Use a meaningful section or revise your sentence. 
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not start a sentence with 'This document describes' -->
    <sch:pattern id="This_document_describes"> 
        <sch:rule context="text ()">
            <sch:report test="matches (., '(T|t)his document describes')" role="info">
                Avoid introducing a topic by writing the phrase this document describes. Use a meangingful topic or revise your sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not start a sentence with 'This topic contains information about' -->
    <sch:pattern id="This_topic_contains_information_about"> 
        <sch:rule context="text ()"> 
            <sch:report test ="matches (., '(T|t)his topic contains information about')" role="info">
                Avoid introducing a topic by writing the phrase this topic contains information about. Use a meaningful topic or revise your sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not start a sentence with 'This section contains information about' -->
    <sch:pattern id="This_section_contains_information_about">
        <sch:rule context="text ()">
            <sch:report test="matches (., '(T|t)his section contains information about')" role="info">
                Avoid introducing a topic by writing the phrase this section contains information about. Use a meaningful topic or revise your sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Do not start a sentence with 'This setup guide explains how to' -->
    <sch:pattern id="This_setup_guide_explains_how_to">
        <sch:rule context="text ()">
            <sch:report test="matches (., '(T|t)his setup guide explains how to')" role="info">
                Avoid introducing a document by writing the phrase this setup guide explains how to. Use a meaningful topic or revise your sentence.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| Punctuation ||| -->

    <!-- Do not use exclamation marks in technical documentation -->
    <sch:pattern id="exclamation">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., '!')" role="info" sqf:fix="exclamation_fix">
                Do not use exclamation marks in technical documents. Use a full stop instead.
            </sch:report>
                <sqf:fix id="exclamation_fix">
                    <sqf:description>
                        <sqf:title>Replace with allowed punctuation: '.'</sqf:title>
                        <sqf:p>Use the correct punctuation, '.'</sqf:p>
                    </sqf:description>
                    <sqf:stringReplace regex="!">.</sqf:stringReplace>
                </sqf:fix>         
        </sch:rule>
    </sch:pattern>
    
    <!-- Use semicolons sparingly in technical documentation -->
    <sch:pattern id="semicolon">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., ';')" role="info">
                Use semicolons sparingly. Use a period instead of a semicolon wherever possible.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    

    
    <sch:pattern id="slash_and_or">
        <sch:rule context="text()">
            <sch:report test="matches(., 'and/or')" sqf:fix="remove_and_or" role="info">
                Do not use 'and/or' in documentation. Use the form 'a or b'.
            </sch:report>
            <sqf:fix id="remove_and_or">
                <sqf:description>
                    <sqf:title>Replace and/or with or</sqf:title>
                </sqf:description>
                <sqf:stringReplace regex="and/or">or</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!-- Avoid using ellipsis in technical documentation -->
    <sch:pattern>
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang,'en-us') and contains(., '…') or contains (., '...')" role="info">
                Use ellipses only when you quote a body of text and some of the text is omitted. 
                Do not include ellipses that are found on the user interface of a product in your documentation.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Avoid hyphenating phrases that begin with an adverb ending in -ly -->
    <sch:pattern>
        <sch:rule context="text()">
            <sch:report test="contains(., 'ly-')" role="info">
                Do not hyphenate phrases that begin with an adverb ending in -ly.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern>
        <sch:rule context="li|p|title">
            <sch:report test="matches(., '&quot;(.*?)&quot;')" role="info">Avoid using quotation marks in technical documentation</sch:report>
        </sch:rule>
    </sch:pattern>
    
    

    
    <sch:pattern id="commaError2">
        <sch:rule context="data[@name = 'product-code']">
            <sch:report test="matches(@content,',')" role="error">Product-codes must not contain commas.</sch:report>
        </sch:rule>
    </sch:pattern>
    

    
    <!--Avoid empty values in prereq elements-->
    <sch:pattern id="prereq_error">
        <sch:rule context="prereq/p">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">
                Avoid an empty &lt;p/> element in prereq elements.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="prereq_error2">
        <sch:rule context="prereq">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">
                Avoid an empty &lt;prereq/> element.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    

    
    <!--Avoid using ampersands in technical content -->
    <sch:pattern id="Avoid_ampersands">
        <sch:rule context="text()">
            <sch:report test="contains (.,'&#38;')" role="info">
                Avoid using ampersands in technical content.
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| Concise language ||| -->
    <!--Come to a conclusion-->
    <sch:pattern id="come_to_conclusion">
        <sch:rule context="text()">
            <sch:report test="matches(., '(C|c)ome to a conclusion')" role="info">
                Use concise language for clarity and to reduce translation costs. Instead of writing "Come to a conclusion", it's better to use "Conclude"
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!--Reach an agreement-->
    <sch:pattern id="reach_agreement">
        <sch:rule context="text()">
            <sch:report test="contains(., 'each an agreement')" role="info">
                Use concise language for clarity and to reduce translation costs. Instead of writing "Reach an agreement", it's better to use "Agree"
            </sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- ||| Units of measurement ||| -->
    <!--psig-->
    <sch:pattern id="psig">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (contains(., 'PSIG') or contains(., 'Psig'))" role="info" sqf:fix="replace_psig">
                The correct spelling of the word is "psig".
            </sch:report>
            <sqf:fix id="replace_psig">
                <sqf:description>
                    <sqf:title>Replace with the correctly styled version</sqf:title>
                </sqf:description>
                <sqf:stringReplace regex="(PSIG|Psig)">psig</sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    
    <!--VDC-->
    <sch:pattern id="VDC">
        <sch:rule context="text()">
            <sch:report test="contains(., 'vdc') or contains(., '\dvdc') or contains(., 'Vdc') or contains(., '\dVdc') or matches(., '\dVDC')" role="info" sqf:fix="replace_vdc">
                The correct spelling is "VDC".
            </sch:report>
            <sqf:fix id="replace_vdc">
                <sqf:description>
                    <sqf:title>Replace with the correctly styled version</sqf:title>
                </sqf:description>
                <sqf:stringReplace regex="(vdc|Vdc|VDC)"> VDC </sqf:stringReplace>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
    

    
    <!--Capitalize and hyphenate Wi-Fi or use a general phrase such as wireless network-->
    <sch:pattern id="WiFi">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and (matches(., '(W|w)i(| )(F|f)i(\s|\W|$)'))" role="info">
                Capitalize and hyphenate when referring specifically to Wi-Fi technologies.
            </sch:report>
        </sch:rule>
    </sch:pattern>   
    
    <!--Do not use an apostrophie to contract the words will and not. Spell out the words will and not.-->
    <sch:pattern id="will_not">
        <sch:rule context="text()">
            <sch:report test='contains(/*/@xml:lang, "en-us") and matches(., "(W|w)on&apos;t")' role='info'>
                Do not use contractions in user documentation for the word won't because it hinders readability. 
            </sch:report>
        </sch:rule>
    </sch:pattern>


    
    <!--Avoid empty topics -->
    <sch:pattern id="empty_topic">
        <sch:rule context="conbody|taskbody|refbody">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">Avoid an empty topic. Use a meaningful topic to introduce the child topics instead.</sch:report>
        </sch:rule> 
    </sch:pattern>
    
    <!--Avoid empty topics with no body -->
    <sch:pattern id="empty_topic_no_body">
        <sch:rule context="concept|task|reference">
            <sch:assert test="conbody|taskbody|refbody" role="warning">Avoid an empty topic. Use a meaningful topic to introduce the child topics instead.</sch:assert>
        </sch:rule>
    </sch:pattern>
    
    <!-- Rule to warn against missing alt text on images -->
    <sch:pattern id="no_alt_desc">
        <sch:rule context="*[contains(@class, ' topic/image ')][not(@conref)][not(@conkeyref)]">
            <sch:assert test="@alt | alt" role="info" sqf:fix="addAltElem">
                For assistive technology and accessibility needs, add alternative text to images. Alt text describe the function of an image. See the Image best practices for accessibility on Confluence for more information. 
                </sch:assert>
            <sqf:fix id="addAltElem">
                <sqf:description>
                    <sqf:title>Add alt element</sqf:title>   
                </sqf:description>
                <sqf:add node-type="element" target="alt"><xsl:processing-instruction name="oxy-placeholder">content="Insert alternative text here"</xsl:processing-instruction></sqf:add>                
            </sqf:fix>
        </sch:rule>
    </sch:pattern>




<!-- Resting place for unused and commented out rules -->

    <!-- Use slashes sparingly in technical documentation -->
<!--    <sch:pattern id="slash">
        <sch:rule context="text()">
            <sch:report test="contains(/*/@xml:lang, 'en-us') and contains(., '/')" role="warning">
                Do not use a slash mark as a substitute for 'or'. If the user interface uses a slash in this way, follow the interface in describing the label, but use 'or' in describing the corresponding action.
            </sch:report>
        </sch:rule>
    </sch:pattern>-->
  
    <!-- Avoid hard coded text in xrefs -->
    <!--<sch:pattern id="xrefError1">
        <sch:rule context="xref" id="empty">
            <sch:assert test="string-length(.) = 0" role="warning">
                The <sch:name/> element should be empty. Do not hard code link text.
            </sch:assert>
        </sch:rule>
    </sch:pattern>-->
    
    <!--Avoid empty values in context elements-->
    <!--<sch:pattern id="context_error">
        <sch:rule context="context/p">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">
                Avoid an empty &lt;p/> element in context elements.
            </sch:report>
        </sch:rule>
    </sch:pattern>-->
    
    <!--<sch:pattern id="context_error2">
        <sch:rule context="context">
            <sch:report test="string-length(normalize-space(.)) = 0" role="warning">
                Avoid an empty &lt;context/> element.
            </sch:report>
        </sch:rule>
    </sch:pattern>-->

    <!--  Rule to warn against empty shortdesc nodes -->
    <!--<sch:pattern is-a="LimitWordsShortdesc">
        <sch:param name="parentElement" value="shortdesc"/>
        <sch:param name="maxWords" value="50"/>
        <sch:param name="message" value="Try to keep short descriptions between 1 word and 50 words. If it is empty, consider deleting it."/>
    </sch:pattern>
    <sch:pattern id="LimitWordsShortdesc" abstract="true">
        <sch:rule context="$parentElement">
            <sch:let name="words" value="count(tokenize(normalize-space(.), ' '))"/>
            <sch:assert test="$words le $maxWords" role="warning">
                $message You have <sch:value-of select="$words"/> word(s).
            </sch:assert>
        </sch:rule>
    </sch:pattern>-->



</sch:schema>