<?xml version="1.0" encoding="UTF-8"?>
<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2"
    xmlns:sqf="http://www.schematron-quickfix.com/validator/process">
    <!--Catches created YYYY-MM-DD errors -->
    <sch:pattern id="createdDateFormatError">
        <sch:rule context="created">
            <sch:assert test="matches(@date, '\d\d\d\d-\d\d-\d\d')" role="error"
                sqf:fix="sqfdateFix">This date value is incorrect. The correct date format is
                YYYY-MM-DD.</sch:assert>
            <sqf:group id="sqfdateFix">
                <sqf:fix id="sqfdateFix1">
                    <sqf:description>
                        <sqf:title>Use the correct date format: YYYY-MM-DD</sqf:title>
                    </sqf:description>
                    <sqf:replace match="@modified" node-type="attribute" target="modified" select="('YYYY-MM-DD')"/>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>

    <!--Catches modified YYYY-MM-DD errors -->
    <sch:pattern id="modifiedDateFormatError">
        <sch:rule context="revised">
            <sch:assert test="matches(@modified, '\d\d\d\d-\d\d-\d\d')" role="error"
                sqf:fix="sqfdateFix">This date value is incorrect. The correct date format is
                YYYY-MM-DD.</sch:assert>
            <sqf:group id="sqfdateFix">
                <sqf:fix id="sqfdateFix1">
                    <sqf:description>
                        <sqf:title>Use the correct date format: YYYY-MM-DD</sqf:title>
                    </sqf:description>
                    <sqf:replace match="@modified" node-type="attribute" target="modified"
                        select="('YYYY-MM-DD')"/>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>

    <!-- Catches instances of audience and prompts user to delete element -->
    <sch:pattern id="audiencenotused">
        <sch:rule context="audience">
            <sch:assert test="exists(audience)" role="error">
                Audience is not currently used. Delete the element from the map.
            </sch:assert>
        </sch:rule>
    </sch:pattern>
            


    <!--Catches permission view errors -->
    <sch:pattern id="permissionViewError">
        <sch:rule context="permissions">
            <sch:assert test="@view='jci-internal' or @view='public' or @view='authorized-partner' or @view='archive'" role="error" sqf:fix="sqfPermissionFix">
                This permissions view value is incorrect. Use jci-internal, public, authorized-partner, or archive.
            </sch:assert>
            <sqf:group id="sqfPermissionFix">
                <sqf:fix id="sqfPermissionFix_jci_internal">
                    <sqf:description>
                        <sqf:title>Replace with 'jci-internal'</sqf:title>
                        <sqf:p>Replace the current value with the approved value 'jci-internal'</sqf:p>
                    </sqf:description>
                    <sqf:replace match="@view" node-type="attribute" target="view">jci-internal</sqf:replace>
                </sqf:fix>
                <sqf:fix id="sqfPermissionFix_public">
                    <sqf:description>
                        <sqf:title>Replace with 'public'</sqf:title>
                        <sqf:p>Replace the current value with the approved value 'public'</sqf:p>
                    </sqf:description>
                    <sqf:replace match="@view" node-type="attribute" target="view">public</sqf:replace>
                </sqf:fix>
                <sqf:fix id="sqfPermissionFix_authorized_partner">
                    <sqf:description>
                        <sqf:title>Replace with 'authorized-partner'</sqf:title>
                        <sqf:p>Replace the current value with the approved value 'authorized-partner'</sqf:p>
                    </sqf:description>
                    <sqf:replace match="@view" node-type="attribute" target="view">authorized-partner</sqf:replace>
                </sqf:fix>
                <sqf:fix id="sqfPermissionFix_archive">
                    <sqf:description>
                        <sqf:title>Replace with 'archive'</sqf:title>
                        <sqf:p>Replace the current value with the approved value 'archive'</sqf:p>
                    </sqf:description>
                    <sqf:replace match="@view" node-type="attribute" target="view">archive</sqf:replace>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>


    <!--Restrict values in brand element-->
    <sch:pattern id="accepted_brands">
        <sch:rule context="brand">
            <sch:assert test="matches(., 
                'American Dynamics|ANSUL|Autocall|BCPro|Bentel|CEM Systems|Champion|CHEMGUARD|Coleman|DSC|EasyIO|Envirco|Enviro-Tec|
                |Evcon|Exacq|Facility Explorer|FireClass|FIREEATER|Fraser-Johnston|FRICK|GEM|Guardian|HYGOOD|Illustra|
                |Johnson Controls|Kantech|LPG|LUX|Luxaire|Metasys|Neuruppin|OpenBlue|PEAK|PENN Controls|PENN Connected|PYRO-CHEM|Quantech|Ruskin|
                |SABO FOAM|Sabroe|SAMSUNG|Sensormatic|Simplex|SKUM|SKYMARK|Software House|TempMaster|THORN SECURITY|Trane|Triatek|
                |Trion|TrueVUE|Tyco|TYCO|Verasys|Visonic|WILLIAMS|YORK|ZETTLER')" role="error">
                This brand name is incorrect. Use the brand names defined by your BU.
            </sch:assert>
<!--            <sqf:group id="sqfbrandFix">
                <sqf:fix id="sqfbrandFix1">
                    <sqf:description>
                        <sqf:title>Use the correct brand name defined by your BU.</sqf:title>
                    </sqf:description>
                    <sqf:replace node-type="element" target="brand" select="('')"/>
                </sqf:fix>
            </sqf:group>-->
        </sch:rule>
    </sch:pattern>

    <!--doctype must be set-->
    <sch:pattern id="doctyperule">
        <sch:rule context="topicmeta">
            <sch:assert test="othermeta[@name='doctype']" role="error"> “doctype” metadata is missing entirely. Add the othermeta element with name="doctype" and content value from the approved list on Confluence: Doc types for DITA and PDF documents. Ignore this error in keydef maps.</sch:assert>
        </sch:rule>
    </sch:pattern>

    <!-- Restrict doctype; This is the master list, any new doctypes must be added here. -->
    <!-- To add a new doctype, a new [  @content='xydoctype' or  ] line must be added -->
    <sch:pattern id="accepted_doctypes">
        <sch:rule context="othermeta[@name = 'doctype']">
            <sch:assert test="@content='Administration Guide' or 
                              @content='Announcement Letter' or 
                              @content='API Developer Guide' or
                              @content='Application Note' or
                              @content='Architectural and Engineering Guide' or
                              @content='Area and Zone Guide' or
                              @content='Best Practices Guide' or 
                              @content='Catalog Page' or
							  @content='Certificate' or
                              @content='Checklist' or 
                              @content='Commissioning Guide' or
                              @content='Communications Setup Guide' or
                              @content='Configuration Guide' or
                              @content='Data Form' or
                              @content='Datasheet' or
                              @content='Declaration' or
							  @content='Documentation Index' or
                              @content='Engineering Guide' or
                              @content='FAQ' or
                              @content='Fixing Guide' or
                              @content='Flash Sheet' or
                              @content='Global Safety Data Sheet' or
                              @content='Guide Specification' or
                              @content='Hardening Guide' or
                              @content='Important Product Information Letter' or
                              @content='Installation Guide' or
							  @content='Installation Operation and Maintenance Guide' or
                              @content='Integration Guide' or
                              @content='Internal Service' or
                              @content='Letter' or
                              @content='Logbook' or
                              @content='Maintenance Guide' or
                              @content='Operation Guide' or
                              @content='Part List' or
                              @content='Planning Guide' or
							  @content='Point List' or
                              @content='Product Application and Design Information' or
                              @content='Product Bulletin' or
                              @content='Product Catalog' or
                              @content='Product Discontinuation Letter' or
                              @content='Product Information Letter' or
                              @content='Product Information Sheet' or
                              @content='Product Recall Action Notice' or
                              @content='Product Release Letter' or
                              @content='Product Safety Alert' or
                              @content='Product Update Action Notice' or
                              @content='Protocol Implementation Conformance Statement' or
                              @content='Quick Start Guide' or
                              @content='Reference Guide' or
                              @content='Release Notes' or
                              @content='Retrofit Guide' or
                              @content='Safety Sheet' or
                              @content='Security and IT Guide' or
                              @content='Service Bulletin' or
                              @content='Service Guide' or
                              @content='Service Information Letter' or
                              @content='Setup Guide' or
                              @content='Specification Engineering Data and Dimensions Guide' or
                              @content='Specification Guide' or
                              @content='Start Up Sheet' or
							  @content='Submittal Drawing' or
                              @content='Technical Bulletin' or
                              @content='Technical Guide' or
                              @content='Troubleshooting Guide' or
                              @content='Upgrade Guide' or
                              @content='User Guide' or
                              @content='Warranty' or
                              @content='White Paper' or
                              @content='Wiring Diagram'"
                        role="error">
                Invalid document type value. Refer to the approved list on Confluence: Doc types for DITA and PDF documents.
            </sch:assert>
        </sch:rule>
    </sch:pattern>


    


    <!-- Don't allow uppercase chars in xml:lang-->
    <sch:pattern id="xmlLangError">
        <sch:rule context="map">
            <!-- assert allows this value only -->
            <sch:assert test="exists(@xml:lang) and matches(@xml:lang, '^[a-z]+-[a-z]+$')" sqf:fix="en_us_add add_xml_lang" role="error">
                The map must have an xml:lang attribute. The attribute must contain only lowercase characters and the code must match the target locale, e.g. 'en-us' not 'en'.
            </sch:assert>
            <sqf:fix id="en_us_add">
                <!--This rule adds an xml:lang attribute and set it to 'en-us'-->
                <sqf:description>
                    <sqf:title>Add the default en-us locale.</sqf:title>
                    <sqf:p>This action will add the xml-lang attribute to the topic and set it as 'en-us'.</sqf:p>
                </sqf:description>
                <sqf:add node-type="attribute" target="xml:lang">en-us</sqf:add>
            </sqf:fix>
            <sqf:fix id="add_xml_lang">
                <!--This rule allows the user to enter their chosen language and it will be set as the xml:lang attribute-->
                <sqf:description>
                    <sqf:title>Input the locale you are using and it will be added along with an xml:lang attribute.</sqf:title>
                    <sqf:p>This action will add the xml:lang attribute to the topic along with the locale you input.</sqf:p>
                </sqf:description>
                <sqf:user-entry name="language_attribute">
                    <sqf:description>
                        <sqf:title>Add the xml:lang attribute and locale.</sqf:title>
                    </sqf:description>
                </sqf:user-entry>
                <sqf:add node-type="attribute" target="xml:lang" select="$language_attribute" />        
            </sqf:fix>
        </sch:rule>
    </sch:pattern>

    <!--clusterId must have upper case i-->
    <sch:pattern id='clusterId'>
		<sch:rule context="othermeta[@name = 'ft:clusterid']">
			<sch:assert test="matches(@name, 'ft:clusterId')" role="error"> <!-- sqf:fix='clusterId_fix' -->
                ft:clusterId must have an upper case letter in Id and not lower case id
            </sch:assert>
            <!-- Hiding sqf because we cannot get it working yet
			<sqf:fix id="clusterId_fix">
                <sqf:description>
                    <sqf:title>Replace 'ft:clusterid' with 'ft:clusterId'</sqf:title>
                </sqf:description>
				<sqf:replace node-type="attribute" target="name" select="replace(., 'ft:clusterid', 'ft:clusterId')"/> 
            </sqf:fix>
			-->
			<!-- Other code we tried but did not work yet either:
			<sqf:replace match="name" target="name" node-type="attribute" select="ft:clusterId"/>
			<sqf:replace node-type="attribute" target="name" select="replace(., 'ft:clusterid', 'ft:clusterId')"/>
			<sqf:replace match="@name, 'ft:clusterid'" node-type="attribute" target="@name, 'ft:clusterId'"/>
			<sqf:stringReplace regex='name="ft:clusterid"'>name="ft:clusterid"</sqf:stringReplace>
			-->
        </sch:rule>
    </sch:pattern>


    <!-- Restrict commas in docnumber, product-code, and vrm version -->
    <sch:pattern id="commaError">
        <sch:rule context="othermeta[@name = 'docnumber']">
            <sch:report test="matches(@content,',')" role="error">Docnumbers must not contain commas.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="commaError2">
        <sch:rule context="othermeta[@name = 'product-code']">
            <sch:report test="matches(@content,',')" role="error">Product-code must not contain commas. If you have multiple product codes, use a separate product-code element for each.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="commaError3">
        <sch:rule context="vrm">
            <sch:report test="matches(@version,',')" role="error">vrm version must not contain commas.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Restrict commas in prodname and category -->
    <sch:pattern id="prodname_comma">
        <sch:rule context="prodname">
            <sch:report test="matches(.,',')" role="error">Prodname metadata must not contain commas. If you have multiple product names, use a separate prodname element for each.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <sch:pattern id="category_comma">
        <sch:rule context="category">
            <sch:report test="matches(.,',')" role="error">Category metadata must not contain commas. If you have multiple categories, use a separate category element for each.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- VRM version should not have the prefix "Release" -->
    <sch:pattern id="vrmError">
        <sch:rule context="vrm">
            <sch:report test="matches(@version,'Release')" role="error">vrm version must not contain the prefix "Release". Use vrmlabel metadata.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- Doc rev should not have the prefix "Rev." -->
    <sch:pattern id="RevError">
        <sch:rule context="othermeta[@name = 'docrev']">
            <sch:report test="matches(@content,'Rev.')" role="error">docrev must not have the prefix "Rev." Use docrevlabel metadata.</sch:report>
        </sch:rule>
    </sch:pattern>
    
    <!-- docpartnumber should not have the prefix "Part No." -->
    <sch:pattern id="DocPartNoError">
        <sch:rule context="othermeta[@name = 'docpartnumber']">
            <sch:report test="matches(@content,'Part (N|n)o.')" role="error">docpartnumber must not have the prefix "Part No." Use docpartnumberlabel metadata.</sch:report>
        </sch:rule>
    </sch:pattern>
	
	<!-- docpartnumber should not be empty -->
	<sch:pattern id="EmptyDocPartNo">
		<sch:rule context="othermeta[@name = 'docpartnumber']">
		    <sch:report test="not(@content) or string-length(@content)=0" role="fatal">docpartnumber must not be blank. Enter the docpartnumber or remove the element from the document.</sch:report>
		</sch:rule> 
	</sch:pattern>

    <!-- metadate tags should not be empty -->
    <sch:pattern id="empty_metadata_tags">
        <sch:rule context="othermeta">
            <sch:report test="not(@content) or string-length(@content)=0" role="fatal">Metadata tags must not be blank.</sch:report>
        </sch:rule> 
    </sch:pattern>
    
    <!--Avoid empty values in map ID-->
    <sch:pattern id="map_id_error">
        <sch:rule context="@id">
            <sch:report test="string-length( normalize-space(.)) = 0" role="error">
                Avoid empty id attributes in ditamaps.
            </sch:report>
        </sch:rule>
    </sch:pattern>    

    <!-- topichead nodes should not be used in a DITA map -->
    <sch:pattern id="NoTopicHeads">
        <sch:rule context="map">
            <sch:report test="topichead" role="error">Don't use topic heads in the DITA map. Use a meaningful topic to introduce the child topics instead.</sch:report>
        </sch:rule> 
    </sch:pattern>
    
	<!-- Remove legacy ixia_locid text -->
	<sch:pattern id="ixia_locid">
		<sch:rule context="*">
			<sch:report test="@ixia_locid" role="error" sqf:fix="removeAttr">
           		Delete the ixia_locid attribute to avoid translation problems.
			</sch:report>
		<sqf:fix id="removeAttr">
			<sqf:description>
				<sqf:title>Delete @ixia_locid attribute</sqf:title>
			</sqf:description>
			<sqf:delete match="@ixia_locid"/>
		</sqf:fix>
		</sch:rule>
	</sch:pattern>

<!-- Resting place for rules that are not in use and hence commented out -->


    <!-- Catches audience type errors. SLM 25APR2023: No longer use audience element. Hide this rule.
    <sch:pattern id="audienceTypeError">
        <sch:rule context="audience">
            <sch:assert test="matches(@type, 'User|Administrator|Developer|Technician|Installer|Architect|Executive|Engineer|Planner|Purchaser')"
                    role="error" sqf:fix="sqfAudienceFix">This audience type value is incorrect. Allowed
                values are User, Administrator, Developer, Technician, Installer, Architect,
                Engineer, Planner, Purchaser, and Executive.</sch:assert>    							  
			<sqf:group id="sqfAudienceFix">
                <sqf:fix id="sqfAudienceFix1">
                    <sqf:description>
                        <sqf:title>Enter the correct audience type value.</sqf:title>
                    </sqf:description>
                    <sqf:replace match="@type" node-type="attribute" target="type" select="(' ')"/>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
    -->

    <!--Restrict values in category element
    <sch:pattern id="RestrictCategoryError">
        <sch:rule context="category">
            <sch:assert
                test="matches(., 'Portables|Foam Hardware|SAPPHIRE|Accessories|Fire Alarm Control Unit')"
                role="error" sqf:fix="sqfcategoryFix">This category value is incorrect. Use the
                category values defined by your BU.</sch:assert>
            <sqf:group id="sqfcategoryFix">
                <sqf:fix id="sqfcategoryFix1">
                    <sqf:description>
                        <sqf:title>Use the correct category value defined by your BU.</sqf:title>
                    </sqf:description>
                    <sqf:replace node-type="element" target="category" select="('')"/>
                </sqf:fix>
            </sqf:group>
        </sch:rule>
    </sch:pattern>
 -->

    <!--Restrict business
    <sch:pattern id="RestrictBusiness1">
        <sch:rule context="othermeta[@name = 'business']">
            <sch:assert test="matches(@content, 'Special Hazards EMEA|Special Hazards NA')"
                role="error" sqf:fix="sqfbusinessfix">Invalid business</sch:assert>
            <sqf:fix id="sqfbusinessfix">
                <sqf:description>
                    <sqf:title>Invalid business</sqf:title>
                </sqf:description>
                <sqf:replace match="othermeta[@content != '']"/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
     -->

    <!-- Don't allow  hyphens in ids
    <sch:pattern id="hyphenUnderscoreError">
        <sch:rule context="@id">

            <sch:report test="matches(., '_')" sqf:fix="ReplaceUnderscore1" role="error">IDs must
                not contain underscores.</sch:report>
            <sqf:fix id="ReplaceUnderscore1">
                <sqf:description>
                    <sqf:title>Replace the underscores with hyphens.</sqf:title>
                </sqf:description>
                <sqf:replace node-type="attribute" target="id" select="replace(., '_', '-')"/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>
     -->

        <!--    <sch:pattern id="noXmlLangErrorMap">
        <sch:rule context="map">
            <sch:assert test="@xml:lang" role="error" sqf:fix="addXmllangMap">map must have xml:lang attribute set.</sch:assert>
            <sqf:fix id="addXmllangMap">
                <sqf:description>
                    <sqf:title>Add the @xml:lang attribute for the map element.</sqf:title>
                </sqf:description>
                <sqf:add node-type="attribute" target="xml:lang"/>
            </sqf:fix>
        </sch:rule>
    </sch:pattern>-->

</sch:schema>
   
    
